<?php


/**
 * get options value
 */

if (!function_exists('thecx_get_option')) {
    function thecx_get_option($thecx_option_key, $thecx_option_default_value = null) {
	    thecx_base_class::initialize_options();
	    $options_array = get_option( "thecx_options_array" );
	    // for demo purpose
	    if ( function_exists( "wd_custom_options" ) ) {
		    $options_array = wd_custom_options( $options_array );
	    }

	    $thecx_meta_value = "";
	    if ( array_key_exists( $thecx_option_key, $options_array ) ) {
		    if ( isset( $options_array[ $thecx_option_key ] ) && ! empty( $options_array[ $thecx_option_key ] ) ) {
			    $thecx_meta_value = esc_attr( $options_array[ $thecx_option_key ] );
		    }

		    if ( $thecx_meta_value == "" ) {
			    $thecx_meta_value = $thecx_option_default_value;
		    }
	    }
	    return $thecx_meta_value;
    }
}

/**
 *
 */
// get options value
if (!function_exists('thecx_save_option')) {
    function thecx_save_option($thecx_option_key, $thecx_option_value = null)
    {
        $options_array = get_option("thecx_options_array");
        $options_array[$thecx_option_key] = $thecx_option_value;
        update_option("thecx_options_array", $options_array);
    }
}

/**
 *
 */
if (!function_exists('thecx_get_categories')) {
    function thecx_get_categories($taxonomy = '')
    {
        $args = array(
            'type' => 'post',
            'hide_empty' => 0
        );

        $output = array();

        $args['taxonomy'] = $taxonomy;
        $categories = get_categories($args);

        if (!empty($categories) && is_array($categories)) {
            foreach ($categories as $category) {
                if (is_object($category)) {
                    $output[$category->name] = $category->slug;
                }
            }
        }

        return $output;
    }
}

/**
 * @param $string
 * @return string
 */
function thecx_removeslashes($string)
{
    $string = implode("", explode("\\", $string));

    return stripslashes(trim($string));
}

/**
 *
 */
function thecx_get_logo_and_title()
{

    if (thecx_get_option('show_the_logo') == 'on' && thecx_get_option('logo_link') != '') { ?>
        <?php $image = thecx_get_option('logo_link');
        ?>
        <a href="<?php echo esc_url(home_url('/')); ?>" rel="home" title="<?php echo bloginfo('name') ?>"
           class="active"><img src="<?php echo esc_url($image); ?>" alt="<?php echo bloginfo('name') ?>"/></a>
    <?php }

    if (thecx_get_option('show_website_title', 'on') == 'on') { ?>
        <a class="site-title" href="<?php echo esc_url(home_url('/')); ?>"><h1><?php echo bloginfo('name') ?></h1>
        </a>
    <?php }

}


/**
 * Get mobile menu ID
 */

if (!function_exists('thecx_mobile_menu_id')) :
    function thecx_mobile_menu_id()
    {
        echo 'mobile-menu';
    }
endif;


/*-----------------add Body Classes------------------------------------------*/
function thecx_body_classes($classes) {
    if (thecx_get_option('boxed_layout') == 'on') {
        $classes[] = 'bg_body_color';
    }

    if (thecx_get_option('wd_page_transitions', 'off') != 'off') {
        $classes[] = 'wd_page_transitions';
    }

    if(is_single()) {
      global $post;
      if ( isset ( $post->ID ) && !get_the_post_thumbnail( $post->ID ) ) {
        $classes[] = 'no-thumbnail';
      }
    }
    return $classes;
}

add_filter('body_class', 'thecx_body_classes');

if (!function_exists('thecx_post_classes')) {
	function thecx_post_classes( $classes ) {
		if ( get_post_type() == "post" ) {
			$digixion_post_format = get_post_format();
			if(!is_single()){
		    $classes[] = 'wd-post';
      }
			switch ( $digixion_post_format ) {
				case 'audio';
					$classes[] = $digixion_post_format;
				case 'gallery';
					$classes[] = 'wd-post--' . $digixion_post_format;
				case 'link';
					$classes[] = 'wd-post--' . $digixion_post_format;
				case 'quote';
					$classes[] = 'wd-post--' . $digixion_post_format;
				case 'video';
					$classes[] = 'wd-post--' . $digixion_post_format;
				case '';
					$classes[] = $digixion_post_format;
			}
		}

	  return $classes;
	}
	add_filter( 'post_class', 'thecx_post_classes' );
}

function thecx_theme_add_editor_styles() {
    add_editor_style('css/custom-editor-style.css');
}
add_action('admin_init', 'thecx_theme_add_editor_styles');



// Moving the Comment Text Field to Bottom
function thecx_move_comment_field_to_bottom( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
}
    
add_filter( 'comment_form_fields', 'thecx_move_comment_field_to_bottom' );
