<?php


class thecx_base_class
{

    private static $instance;
    public $helpers;
    public $customizer;
    public $activation;
    public $integrations;
    public $widgets;
    public $template;
    public $page_settings;
    public $widgetized_pages;

    public static function instance()
    {
        if (!isset(self::$instance) && !(self::$instance instanceof thecx_base_class)) {
            self::$instance = new self;
        }

        return self::$instance;
    }

    public function __construct()
    {
        $this->default_parameters();
        $this->setup();
    }

    // Integration getter helper
    public function get($integration)
    {
        return $this->integrations->get($integration);
    }


    private function setup()
    {
        add_action('after_setup_theme', array($this, 'setup_theme'));
    }

    public function setup_theme()
    {
        load_theme_textdomain('thecx', get_template_directory() . '/languages');
        add_editor_style('css/editor-style.css');

        add_theme_support('custom-background', apply_filters('thecx_custom_background_args', array('default-color' => 'ffffff',
            'default-image' => '',)));

    }

    public function default_parameters()
    {


        // Colors
        define('WD_PRIMARY_COLOR', '#335cff');
        define('WD_PRIMARY_COLOR_CONTRAST', '#FFFFFF');
        define('WD_SECONDARY_COLOR', '#3a46d1');
        define('WD_ACCENT_COLOR', '#e80d31');
        define('WD_TEXT_COLOR', '#0f0f0f');
        define('WD_SECONDARY_TEXT_COLOR', '#5f5f5f');
        define('WD_HEADINGS_COLOR', '#1c1c1d');
        define('WD_BODY_BG_COLOR', '#fff');

        define('WD_GRAY_1_COLOR', '#fdfdfd');
        define('WD_GRAY_2_COLOR', '#f9f9f9');
        define('WD_GRAY_3_COLOR', '#f3f3f3');
        define('WD_GRAY_4_COLOR', '#e9e9e9');

        // Layout
        define('WD_MENU_STYLE', 'creative');
        define('WD_BOXED_LAYOUT', "off");
        define('WD_MENU_ALIGN', "left");
        define('WD_MENU_MOBILE_LAYOUT', "on");
        define('WD_HEADER_CONTAIN_TO_GRID', "on");
        define('WD_STICK_MENU_TO_TOP', "on");
        define('WD_PAGE_LOADING_ANIMATION', "off");
        define('WD_SHOW_THE_LOGO', "off");
        define('WD_SHOW_WEBSITE_TITLE', "on");
        define('WD_LOGO_HEIGHT', '40');

        define('SHOW_LANGUAGE_WIDGET', "on");
        define('LANGUAGE_AREA_HTML', "");

        //Page settings
        define('WD_PAGE_TITLE_FONT_SIZE', "66px");
        define('WD_PAGE_TITLEBAR_ALIGN', "left");
        define('WD_PAGE_TITLEBAR_TITLE_PADDING', "0 15px 60px 0");
        define('WD_PAGE_TITLEBAR_PADDING', "268px 0 80px");

        // Topbar Colors
        define('WD_HEADER_BG_COLOR', '#FFF');
        define('WD_NAV_TEXT_COLOR', '#1C1C1D');
        define('WD_STICKY_NAV_BG_COLOR', '#FFF');
        define('WD_STICKY_NAV_TEXT_COLOR', '#1C1C1D');
        define('WD_HOVER_STICKY_NAV_TEXT_COLOR', '#335CFF');
        define('WD_HOVER_NAV_TEXT_COLOR', '#335CFF');

        // Footer Colors
        define('WD_FOOTER_BG_COLOR', '#121114');
        define('WD_FOOTER_BACKGROUND_IMAGE', '');
        define('WD_FOOTER_TEXT_COLOR', '#D4D4D4');
        define('WD_COPYRIGHT_BG_COLOR', '#121114');
        define('WD_COPYRIGHT_TEXT_COLOR', '#D4D4D4');

        // Typography
        define('WD_USE_DEFAULT_FONT', "on");
        define('WD_BODY_FONT_FAMILY', "Open Sans");
        define('WD_BODY_FONT_FAMILY_FALLBACK', "sans-serif");
        define('WD_BODY_FONT_WEIGHT', 400);

        define('WD_HEAD_FONT_FAMILY', "Khula");
        define('WD_HEAD_FONT_FAMILY_FALLBACK', "'Khula', Roboto sans-serif");

        define('WD_NAV_FONT_FAMILY', "Open Sans");
        define('WD_NAV_FONT_FAMILY_FALLBACK', "'Open Sans', sans-serif");


    }

    /**
     *
     * // initialize options
     */

    public static function initialize_options()
    {
        if (!get_option("thecx_options_array")) {
            $options_array = get_option("thecx_options_array");
            $options_array = array(

                // Colors
                "primary_color"         => WD_PRIMARY_COLOR,
                "primary_color_contrast"=> WD_PRIMARY_COLOR_CONTRAST,
                "secondary_color"       => WD_SECONDARY_COLOR,
                "accent_color"          => WD_ACCENT_COLOR,
                "text_color"            => WD_TEXT_COLOR,
                "secondary_text_color"  => WD_SECONDARY_TEXT_COLOR,
                "headings-color"        => WD_HEADINGS_COLOR,
                "body_bg_color"         => WD_BODY_BG_COLOR,

                "gray_1_color"          => WD_GRAY_1_COLOR,
                "gray_2_color"          => WD_GRAY_2_COLOR,
                "gray_3_color"          => WD_GRAY_3_COLOR,
                "gray_4_color"          => WD_GRAY_4_COLOR,

                // Layout
                "wd_menu_style"         => WD_MENU_STYLE,
                "boxed_layout"          => WD_BOXED_LAYOUT,
                "menu_align"            => WD_MENU_ALIGN,
                "menu_mobile_layout"    => WD_MENU_MOBILE_LAYOUT,
                "header_contain_to_grid" => WD_HEADER_CONTAIN_TO_GRID,
                "stick_menu_to_top"     => WD_STICK_MENU_TO_TOP,
                "page_loading_animation" => WD_PAGE_LOADING_ANIMATION,
                "show_the_logo"         => WD_SHOW_THE_LOGO,
                "show_website_title"    => WD_SHOW_WEBSITE_TITLE,                
                "logo_height"           => WD_LOGO_HEIGHT,
                "logo_link"             => get_template_directory_uri() . "/images/logo.png",
                "logo_padding"          => "",

                "show_language_widget"  => SHOW_LANGUAGE_WIDGET,
                "language_area_html"    => LANGUAGE_AREA_HTML,

                //Page settings
                "title_page_bg"         => "",
                "page_title_font_size"  => WD_PAGE_TITLE_FONT_SIZE,
                "titlebar_align"        => WD_PAGE_TITLEBAR_ALIGN,
                "page_title_padding"    => WD_PAGE_TITLEBAR_TITLE_PADDING,
                "titlebar_padding"      => WD_PAGE_TITLEBAR_PADDING,

                // Topbar Colors
                "header_bg_color"       => WD_HEADER_BG_COLOR,
                "nav_text_color"        => WD_NAV_TEXT_COLOR,
                "sticky_nav_bg_color"   => WD_STICKY_NAV_BG_COLOR,
                "sticky_nav_text_color" => WD_STICKY_NAV_TEXT_COLOR,
                "hover_sticky_nav_text_color" => WD_HOVER_STICKY_NAV_TEXT_COLOR,
                "hover_nav_text_color"  => WD_HOVER_NAV_TEXT_COLOR,


                // Footer Colors
                "footer_bg_color"       => WD_FOOTER_BG_COLOR,
                "footer-background-image"       => WD_FOOTER_BACKGROUND_IMAGE,
                "footer_text_color"     => WD_FOOTER_TEXT_COLOR,
                "copyright_bg_color"    => WD_COPYRIGHT_BG_COLOR,
                "copyright_text_color"  => WD_COPYRIGHT_TEXT_COLOR,
                "copyright_text" => "",
                "powered_text" => "",
                "footer_column" => "four_columns",



                // Typography
                
                "use_default_font" => WD_USE_DEFAULT_FONT,
                "body_font_family" => WD_BODY_FONT_FAMILY,
                "body_font_style" => "normal",
                "body_font_size" => "",
                "body_font_weight" => WD_BODY_FONT_WEIGHT,
                "body_letter_spacing" => "",
                "body_font_subsets" => "",
                "body_font_to_load" => "300 400 500 600 700 800",

                "head_font_family" => WD_HEAD_FONT_FAMILY,
                "head_font_style" => "normal",
                "head_font_weight" => "620",
                "head_font_subsets" => "latin",
                "head_letter_spacing" => "",
                "head_font_to_load" => "100 300 400 500 600 700 900",

                "nav_font_family" => WD_NAV_FONT_FAMILY,
                "nav_font_style" => "normal",
                "nav_font_weight" => "700",
                "nav_font_size" => "",
                "nav_font_subsets" => "latin",
                "nav_letter_spacing" => "",
                "nav_font_to_load" => "300 400 500 600 700",
                


                "google_key_map" => "AIzaSyDcmvSA1VvwVKgtNBzsswD3rzafLCrRcuk",
                "404_background_image" => "",

                "products_per_page" => "9",
                "product_column" => "4",
                "single_product_titlebar" => "on",
                



                "wd_theme_custom_js" => "",

                "wd_call_to_action" => "",
                "body_background_image" => "",
                "bg_home_page" => "Upload",


            );
            update_option("thecx_options_array", $options_array);
        }
    }

}